@@ -2,11 +2,12 @@
 #define __GVCONTACTSTABLE_H__
 
 #include "global.h"
-#include "ContactsModel.h"
 
 #include <QtNetwork>
 #include <QtDeclarative>
 
+class ContactsModel;
+
 class GVContactsTable : public QObject
 {
     Q_OBJECT
